﻿using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.ServiceModel;
using System.ServiceModel.Activation;
using System.ServiceModel.Web;
using System.Web.Script.Services;

namespace CustomWcfRestService
{
    [ServiceContract]
    [AspNetCompatibilityRequirements(RequirementsMode = AspNetCompatibilityRequirementsMode.Required)]
    [ServiceBehavior(InstanceContextMode = InstanceContextMode.PerCall)]
    public class CustomService
    {
        [WebGet(UriTemplate = "/GetPeople", RequestFormat = WebMessageFormat.Json, ResponseFormat = WebMessageFormat.Json)]
        public List<Person> GetPeople()
        {
            using(var ctx = new Context())
            {
                ctx.Configuration.LazyLoadingEnabled = false;
                ctx.Configuration.ProxyCreationEnabled = false;
                return ctx.People.OrderBy(one => one.LastName).ThenBy(two => two.FirstName).ToList();
            }
        }

        [WebInvoke(UriTemplate = "/Create", Method = "POST", RequestFormat = WebMessageFormat.Json, ResponseFormat = WebMessageFormat.Json)]
        public Person Create(Person person)
        {
            using (var ctx = new Context())
            {
                ctx.Entry(person).State = EntityState.Added;
                ctx.SaveChanges();
                return person;
            }
        }

        [WebGet(UriTemplate = "/GetPerson?id={id}", RequestFormat = WebMessageFormat.Json, ResponseFormat = WebMessageFormat.Json)]
        public Person Get(int id)
        {
            using (var ctx = new Context())
            {
                ctx.Configuration.LazyLoadingEnabled = false;
                ctx.Configuration.ProxyCreationEnabled = false;
                return ctx.People.Find(id);
            }
        }

        [WebInvoke(UriTemplate = "/UpdatePerson", Method = "POST", RequestFormat = WebMessageFormat.Json, ResponseFormat = WebMessageFormat.Json)]
        public Person Update(Person person)
        {
            using (var ctx = new Context())
            {
                ctx.Entry(person).State = EntityState.Modified;
                ctx.SaveChanges();
                return person;
            }
        }

        [WebInvoke(UriTemplate = "/GetPerson?id={id}", Method = "POST", RequestFormat = WebMessageFormat.Json, ResponseFormat = WebMessageFormat.Json)]
        public void Delete(int id)
        {
            using (var ctx = new Context())
            {
                var person = new Person {ID = id};
                ctx.Entry(person).State = EntityState.Deleted;
                ctx.SaveChanges();
            }
        }

    }
}
